#include "StdAfx.h"
#include "WorkGroupModel.h"

WorkGroupModel::WorkGroupModel(void)
{
    Clear();
}

WorkGroupModel::~WorkGroupModel(void)
{
	
}

void WorkGroupModel::AddMember( const NE_MEMBER_DATA& data )
{
	ORG_MEMBER_DATA memberData;
	memberData.neMemberData = data;
	memberData.eStatus = ustOFFLINE;
	memberData.eIPTStatus = iptstNA;

	m_memberVector.push_back(memberData);
}

void WorkGroupModel::AddBuddyMember(const NE_MEMBER_DATA& data, GTUserStatusType eUserStatus, NTIPTStatusType eIPTStatus)
{
	ORG_MEMBER_DATA memberData;
	memberData.neMemberData = data;
	memberData.eStatus = eUserStatus;
	memberData.eIPTStatus = eIPTStatus;
	CString strUserID = memberData.neMemberData.strUserId.c_str();
	m_mapAllMember[strUserID] = memberData;
}

void WorkGroupModel::AddSelectdUser( const NE_MEMBER_DATA& data )
{
	ORG_MEMBER_DATA memberData;
	memberData.neMemberData = data;
	memberData.eStatus = ustOFFLINE;
	memberData.eIPTStatus = iptstNA;

	m_selectedUserVector.push_back(memberData);
}

const std::vector<ORG_MEMBER_DATA> WorkGroupModel::GetMemberVector() const
{
	return m_memberVector;
}

const std::vector<ORG_MEMBER_DATA> WorkGroupModel::GetSelectedUserVector() const
{
	return m_selectedUserVector;
}

const NE_MEMBER_DATA WorkGroupModel::GetMember( int index )
{
	NE_MEMBER_DATA data;

	if (index < (int)m_memberVector.size())
	{
		data = m_memberVector[index].neMemberData;
	}
	else
	{
		ASSERT(FALSE);
	}

	return data;
}

const NE_MEMBER_DATA WorkGroupModel::GetMember(LPCWSTR strUserID)
{
	NE_MEMBER_DATA data;
	std::vector<ORG_MEMBER_DATA>::iterator memberIterator = m_memberVector.begin();
	for (; memberIterator != m_memberVector.end(); ++memberIterator)
	{
		if (wcscmp(memberIterator->neMemberData.strUserId.c_str(), strUserID) == 0)
		{
			data = memberIterator->neMemberData;
			return data;
		}
	}

	CString strID = strUserID;
	std::map<CString, ORG_MEMBER_DATA>::iterator it = m_mapAllMember.find(strID);
	if (it != m_mapAllMember.end())
	{
		data = m_mapAllMember[strID].neMemberData;
		return data;
	}
	
	return data;
}

void WorkGroupModel::AddWorkGroup( const GT_ORG_GROUP_DATA& data )
{
	const GT_ORG_GROUP_DATA groupData = data;
	m_workGroupVector.push_back(groupData);
}

const std::vector<GT_ORG_GROUP_DATA> WorkGroupModel::GetWorkGroupVector() const
{
	return m_workGroupVector;
}

void WorkGroupModel::AddOrgGroup( const GT_ORG_GROUP_DATA& data )
{
	const GT_ORG_GROUP_DATA groupData = data;
	m_orgGroupVector.push_back(groupData);
}

const std::vector<GT_ORG_GROUP_DATA> WorkGroupModel::GetOrgGroupVector() const
{
	return m_orgGroupVector;
}

void WorkGroupModel::Clear(BOOL bDeteleAllData)
{
	m_nSearchTotal = 0;
	m_nSearchPage = 0;
	m_memberVector.clear();
	ClearGroups();
	if (bDeteleAllData)
	{
		m_mapAllMember.clear();
	}
}

void WorkGroupModel::ClearMembers()
{
	m_nSearchTotal = 0;
	m_nSearchPage = 0;
	for (size_t i=0; i<m_memberVector.size(); ++i)
	{
		CString strUserID = m_memberVector[i].neMemberData.strUserId.c_str();
		m_mapAllMember[strUserID] = m_memberVector[i];
	}
	m_memberVector.clear();
}

void WorkGroupModel::ClearGroups()
{
	m_workGroupVector.clear();
	m_orgGroupVector.clear();
}

void WorkGroupModel::ClearSelectedUserVector()
{
	m_selectedUserVector.clear();
}

void WorkGroupModel::UpdateMemberStatus(LPCWSTR strUserID, GTUserStatusType eUserStatus)
{
	//   
	std::vector<ORG_MEMBER_DATA>::iterator memberIterator = m_memberVector.begin();

	for (; memberIterator != m_memberVector.end(); memberIterator++)
	{
		if (wcscmp(memberIterator->neMemberData.strUserId.c_str(), strUserID) == 0)
		{
			memberIterator->eStatus = eUserStatus;
			break;
		}
	}

	//  ߰â  
	memberIterator = m_selectedUserVector.begin();
	for (; memberIterator != m_selectedUserVector.end(); memberIterator++)
	{
		if (wcscmp(memberIterator->neMemberData.strUserId.c_str(), strUserID) == 0)
		{
			memberIterator->eStatus = eUserStatus;
			break;
		}
	}
	
	CString strID = strUserID;
	std::map<CString, ORG_MEMBER_DATA>::iterator it = m_mapAllMember.find(strID);
	if (it != m_mapAllMember.end())
	{
		m_mapAllMember[strID].eStatus = eUserStatus;
	}
}

void WorkGroupModel::UpdateMemberIPTStatus( LPCWSTR strUserID, NTIPTStatusType eUserIPTStatus )
{
	std::vector<ORG_MEMBER_DATA>::iterator memberIterator = m_memberVector.begin();

	for (; memberIterator != m_memberVector.end(); ++memberIterator)
	{
		if (wcscmp(memberIterator->neMemberData.strUserId.c_str(), strUserID) == 0)
		{
			memberIterator->eIPTStatus = eUserIPTStatus;
			break;
		}
	}

	memberIterator = m_selectedUserVector.begin();
	for (; memberIterator != m_selectedUserVector.end(); ++memberIterator)
	{
		if (wcscmp(memberIterator->neMemberData.strUserId.c_str(), strUserID) == 0)
		{
			memberIterator->eIPTStatus = eUserIPTStatus;
			break;
		}
	}

	CString strID = strUserID;
	std::map<CString, ORG_MEMBER_DATA>::iterator it = m_mapAllMember.find(strID);
	if (it != m_mapAllMember.end())
	{
		m_mapAllMember[strID].eIPTStatus = eUserIPTStatus;
	}
}


WSTRING WorkGroupModel::GetMemberWorkStatus( LPCWSTR strUserID )
{
	GTUserStatusType returnStatus = ustOFFLINE;

	std::vector<ORG_MEMBER_DATA>::iterator memberIterator = m_memberVector.begin();

	for (; memberIterator != m_memberVector.end(); memberIterator++)
	{
		if (wcscmp(memberIterator->neMemberData.strUserId.c_str(), strUserID) == 0)
		{
			return memberIterator->neMemberData.strWorkStatus;
		}
	}

	memberIterator = m_selectedUserVector.begin();

	for (; memberIterator != m_selectedUserVector.end(); memberIterator++)
	{
		if (wcscmp(memberIterator->neMemberData.strUserId.c_str(), strUserID) == 0)
		{
			return memberIterator->neMemberData.strWorkStatus;
		}
	}

	CString strID = strUserID;
	std::map<CString, ORG_MEMBER_DATA>::iterator it = m_mapAllMember.find(strID);
	if (it != m_mapAllMember.end())
	{
		return memberIterator->neMemberData.strWorkStatus;
	}

	return _T("");
}


GTUserStatusType WorkGroupModel::GetMemberStatus( LPCWSTR strUserID )
{
	GTUserStatusType returnStatus = ustOFFLINE;

	std::vector<ORG_MEMBER_DATA>::iterator memberIterator = m_memberVector.begin();

	for (; memberIterator != m_memberVector.end(); memberIterator++)
	{
		if (wcscmp(memberIterator->neMemberData.strUserId.c_str(), strUserID) == 0)
		{
			returnStatus = memberIterator->eStatus;
			return returnStatus;
		}
	}

	memberIterator = m_selectedUserVector.begin();

	for (; memberIterator != m_selectedUserVector.end(); memberIterator++)
	{
		if (wcscmp(memberIterator->neMemberData.strUserId.c_str(), strUserID) == 0)
		{
			returnStatus = memberIterator->eStatus;
			return returnStatus;
		}
	}

	CString strID = strUserID;
	std::map<CString, ORG_MEMBER_DATA>::iterator it = m_mapAllMember.find(strID);
	if (it != m_mapAllMember.end())
	{
		returnStatus =m_mapAllMember[strID].eStatus;
		return returnStatus;
	}

	return returnStatus;
}

NTIPTStatusType WorkGroupModel::GetMemberIPTStatus( LPCWSTR strUserID )
{
	NTIPTStatusType returnStatus = iptstIDLE;

	std::vector<ORG_MEMBER_DATA>::iterator memberIterator = m_memberVector.begin();

	for (; memberIterator != m_memberVector.end(); memberIterator++)
	{
		if (wcscmp(memberIterator->neMemberData.strUserId.c_str(), strUserID) == 0)
		{
			returnStatus = memberIterator->eIPTStatus;
			break;
		}
	}

	CString strID = strUserID;
	std::map<CString, ORG_MEMBER_DATA>::iterator it = m_mapAllMember.find(strID);
	if (it != m_mapAllMember.end())
	{
		returnStatus =m_mapAllMember[strID].eIPTStatus;
		return returnStatus;
	}

	return returnStatus;
}
